CHANGELOG
=========

1.1 - 2017-06-09
----------------

- added request and json_request helpers (#50)
- added session setup and teardown fixtures (#52)
- added set_var & get_var helpers (#54)
- fixed thhe code generated by molostart (#55)


1.0 - 2017-03-23
----------------

- Initial stable release
